@@ -30,17 +30,35 @@
 
 #include "dhcpcd.h"
 
+/* Limit queue size per fd */
+#define CONTROL_QUEUE_MAX	100
+
+struct fd_data {
+	TAILQ_ENTRY(fd_data) next;
+	char *data;
+	size_t data_len;
+	uint8_t freeit;
+};
+TAILQ_HEAD(fd_data_head, fd_data);
+
 struct fd_list {
-	struct fd_list *next;
+	TAILQ_ENTRY(fd_list) next;
 	struct dhcpcd_ctx *ctx;
 	int fd;
-	int listener;
+	unsigned int flags;
+	struct fd_data_head queue;
+	struct fd_data_head free_queue;
 };
+TAILQ_HEAD(fd_list_head, fd_list);
+
+#define FD_LISTEN	(1<<0)
+#define FD_UNPRIV	(1<<1)
 
 int control_start(struct dhcpcd_ctx *, const char *);
 int control_stop(struct dhcpcd_ctx *);
 int control_open(struct dhcpcd_ctx *, const char *);
 ssize_t control_send(struct dhcpcd_ctx *, int, char * const *);
+int control_queue(struct fd_list *fd, char *data, size_t data_len, uint8_t fit);
 void control_close(struct dhcpcd_ctx *ctx);
 
 #endif
