@@ -230,6 +230,11 @@ ipv4_ifcmp(const struct interface *si, const struct interface *ti)
 		return -1;
 	if (!sis->new && tis->new)
 		return 1;
+	/* Always prefer proper leases */
+	if (!(sis->added & STATE_FAKE) && (sis->added & STATE_FAKE))
+		return -1;
+	if ((sis->added & STATE_FAKE) && !(sis->added & STATE_FAKE))
+		return 1;
 	/* If we are either, they neither have a lease, or they both have.
 	 * We need to check for IPv4LL and make it non-preferred. */
 	if (sis->new && tis->new) {
@@ -623,7 +628,10 @@ ipv4_buildroutes(struct dhcpcd_ctx *ctx)
 			rt->src.s_addr = state->addr.s_addr;
 			/* Do we already manage it? */
 			if ((or = find_route(ctx->ipv4_routes, rt, NULL))) {
-				if (or->iface != ifp ||
+				if (state->added & STATE_FAKE)
+					continue;
+				if (or->flags & STATE_FAKE ||
+				    or->iface != ifp ||
 				    or->src.s_addr != state->addr.s_addr ||
 				    rt->gate.s_addr != or->gate.s_addr ||
 				    rt->metric != or->metric)
@@ -634,9 +642,13 @@ ipv4_buildroutes(struct dhcpcd_ctx *ctx)
 				TAILQ_REMOVE(ctx->ipv4_routes, or, next);
 				free(or);
 			} else {
-				if (n_route(rt) != 0)
+				if (!(state->added & STATE_FAKE) &&
+				    n_route(rt) != 0)
 					continue;
 			}
+			rt->flags = STATE_ADDED;
+			if (state->added & STATE_FAKE)
+				rt->flags |= STATE_FAKE;
 			TAILQ_REMOVE(dnr, rt, next);
 			TAILQ_INSERT_TAIL(nrs, rt, next);
 		}
@@ -786,7 +798,8 @@ ipv4_applyaddr(void *arg)
 						} else {
 							ipv4_addaddr(ifn,
 							    &nstate->lease);
-							nstate->added = 1;
+							nstate->added =
+							    STATE_ADDED;
 						}
 						break;
 					}
@@ -863,7 +876,7 @@ ipv4_applyaddr(void *arg)
 	    state->addr.s_addr != 0)
 		delete_address(ifp);
 
-	state->added = 1;
+	state->added = STATE_ADDED;
 	state->defend = 0;
 	state->addr.s_addr = lease->addr.s_addr;
 	state->net.s_addr = lease->net.s_addr;
